@@ -5,13 +5,13 @@
 """
 
 __author__ = 'Ryan Fisher <ryan.fisher@ligo.org>'
-__version__ = 'dqsegdb-release-1-3-2'
-__date__ = '2016-06-23 20:23:17 +0000'
+__version__ = 'dqsegdb-release-1-4-0'
+__date__ = '2016-10-24 17:36:19 +0000'
 
-version = 'dqsegdb-release-1-3-2'
-git_id = 'afb8446a516ef79fa3ec0f36af5366bc135863ce'
-git_branch = 'dqsegdb-release-branch-1-3'
-git_tag = 'dqsegdb-release-1-3-2'
+version = 'dqsegdb-release-1-4-0'
+git_id = 'cb86841097139dd8332cba2bfa13bcf8d8e01443'
+git_branch = 'dqsegdb-1-4-branch'
+git_tag = 'dqsegdb-release-1-4-0'
 git_author = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_committer = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_status = 'UNCLEAN: Modified working tree'
